Class: ActiveRecord::ConnectionAdapters::ODBCAdapter
- Inherits:
-
AbstractAdapter
- Object
- AbstractAdapter
- ActiveRecord::ConnectionAdapters::ODBCAdapter
- Includes:
- ODBCAdapter::DatabaseLimits, ODBCAdapter::DatabaseStatements, ODBCAdapter::Quoting, ODBCAdapter::SchemaStatements
- Defined in:
- lib/active_record/connection_adapters/odbc_adapter.rb
Direct Known Subclasses
ODBCAdapter::Adapters::MySQLODBCAdapter, ODBCAdapter::Adapters::NullODBCAdapter, ODBCAdapter::Adapters::PostgreSQLODBCAdapter
Constant Summary collapse
- ADAPTER_NAME =
'ODBC'.freeze
- BOOLEAN_TYPE =
'BOOLEAN'.freeze
- ERR_DUPLICATE_KEY_VALUE =
23505- ERR_QUERY_TIMED_OUT =
/Query has timed out/
Constants included from ODBCAdapter::DatabaseStatements
ODBCAdapter::DatabaseStatements::SQL_NO_NULLS, ODBCAdapter::DatabaseStatements::SQL_NULLABLE, ODBCAdapter::DatabaseStatements::SQL_NULLABLE_UNKNOWN
Instance Attribute Summary collapse
-
#database_metadata ⇒ Object
readonly
Returns the value of attribute database_metadata.
Instance Method Summary collapse
-
#active? ⇒ Boolean
Checks whether the connection to the database is still active.
-
#adapter_name ⇒ Object
Returns the human-readable name of the adapter.
-
#disconnect! ⇒ Object
Disconnects from the database if already connected.
-
#initialize(connection, logger, database_metadata) ⇒ ODBCAdapter
constructor
A new instance of ODBCAdapter.
- #new_column(name, default, sql_type_metadata, null, table_name, default_function = nil, collation = nil, native_type = nil) ⇒ Object
-
#reconnect! ⇒ Object
(also: #reset!)
Disconnects from the database if already connected, and establishes a new connection with the database.
-
#supports_migrations? ⇒ Boolean
Does this adapter support migrations? Backend specific, as the abstract adapter always returns
false.
Methods included from ODBCAdapter::SchemaStatements
#columns, #current_database, #foreign_keys, #index_name, #indexes, #native_database_types, #primary_key, #tables, #views
Methods included from ODBCAdapter::Quoting
#quote_column_name, #quote_string, #quoted_date
Methods included from ODBCAdapter::DatabaseStatements
#begin_db_transaction, #commit_db_transaction, #default_sequence_name, #exec_delete, #exec_query, #exec_rollback_db_transaction, #execute
Methods included from ODBCAdapter::DatabaseLimits
Constructor Details
#initialize(connection, logger, database_metadata) ⇒ ODBCAdapter
Returns a new instance of ODBCAdapter.
85 86 87 88 89 |
# File 'lib/active_record/connection_adapters/odbc_adapter.rb', line 85 def initialize(connection, logger, ) super(connection, logger) @connection = connection = end |
Instance Attribute Details
#database_metadata ⇒ Object (readonly)
Returns the value of attribute database_metadata.
83 84 85 |
# File 'lib/active_record/connection_adapters/odbc_adapter.rb', line 83 def end |
Instance Method Details
#active? ⇒ Boolean
Checks whether the connection to the database is still active. This includes checking whether the database is actually capable of responding, i.e. whether the connection isn’t stale.
108 109 110 |
# File 'lib/active_record/connection_adapters/odbc_adapter.rb', line 108 def active? @connection.connected? end |
#adapter_name ⇒ Object
Returns the human-readable name of the adapter. Use mixed case - one can always use downcase if needed.
93 94 95 |
# File 'lib/active_record/connection_adapters/odbc_adapter.rb', line 93 def adapter_name ADAPTER_NAME end |
#disconnect! ⇒ Object
Disconnects from the database if already connected. Otherwise, this method does nothing.
128 129 130 |
# File 'lib/active_record/connection_adapters/odbc_adapter.rb', line 128 def disconnect! @connection.disconnect if @connection.connected? end |
#new_column(name, default, sql_type_metadata, null, table_name, default_function = nil, collation = nil, native_type = nil) ⇒ Object
132 133 134 |
# File 'lib/active_record/connection_adapters/odbc_adapter.rb', line 132 def new_column(name, default, , null, table_name, default_function = nil, collation = nil, native_type = nil) ::ODBCAdapter::Column.new(name, default, , null, table_name, default_function, collation, native_type) end |
#reconnect! ⇒ Object Also known as: reset!
Disconnects from the database if already connected, and establishes a new connection with the database.
114 115 116 117 118 119 120 121 122 123 |
# File 'lib/active_record/connection_adapters/odbc_adapter.rb', line 114 def reconnect! disconnect! @connection = if .key?(:dsn) ODBC.connect([:dsn], [:username], [:password]) else ODBC::Database.new.drvconnect([:driver]) end super end |
#supports_migrations? ⇒ Boolean
Does this adapter support migrations? Backend specific, as the abstract adapter always returns false.
99 100 101 |
# File 'lib/active_record/connection_adapters/odbc_adapter.rb', line 99 def supports_migrations? true end |